@@ -205,7 +205,7 @@ likel <- function(p){
 	if(np>np1){
 		if(np3-np1==1)pshape <- rep(p[np3],states)
 		else pshape <- p[np2:np3]}
-	z <- .Fortran("cphidden",
+	z <- .Fortran("cphidden_f",
 		x=as.double(p),
 		as.integer(states),
 		iq=as.integer(nosubj),
@@ -259,7 +259,7 @@ like <- function(p){
 	if(np>np1){
 		if(np3-np1==1)pshape <- rep(p[np3],states)
 		else pshape <- p[np2:np3]}
-	z <- .Fortran("cphidden",
+	z <- .Fortran("cphidden_f",
 		x=as.double(p),
 		as.integer(states),
 		iq=as.integer(nosubj),
